import { IS_CODE, IS_ITALIC, IS_BOLD, IS_UNDERLINE } from "../../FormatConstants.js";
import { $createTextNode } from "lexical";
function isOpeningUnderlineNode(node) {
  return node.type === "html" && node.value === "<u>";
}
function isClosingUnderlineNode(node) {
  return node.type === "html" && node.value === "</u>";
}
function isJsxUnderlineNode(node) {
  return node.type === "mdxJsxTextElement" && node.name === "u";
}
function isJsxCodeNode(node) {
  return node.type === "mdxJsxTextElement" && node.name === "code";
}
function isOpeningCodeNode(node) {
  return node.type === "html" && node.value === "<code>";
}
function isClosingCodeNode(node) {
  return node.type === "html" && node.value === "</code>";
}
const JsxCodeVisitor = {
  testNode: isJsxCodeNode,
  visitNode({ mdastNode, actions, lexicalParent }) {
    actions.addFormatting(IS_CODE);
    actions.visitChildren(mdastNode, lexicalParent);
  }
};
const OpeningCodeVisitor = {
  testNode: isOpeningCodeNode,
  visitNode({ actions, mdastParent }) {
    actions.addFormatting(IS_CODE, mdastParent);
  }
};
const ClosingCodeVisitor = {
  testNode: isClosingCodeNode,
  visitNode({ actions, mdastParent }) {
    actions.removeFormatting(IS_CODE, mdastParent);
  }
};
const MdCodeVisitor = {
  testNode: "inlineCode",
  visitNode({ mdastNode, actions }) {
    actions.addAndStepInto($createTextNode(mdastNode.value).setFormat(actions.getParentFormatting() | IS_CODE));
  }
};
const MdEmphasisVisitor = {
  testNode: "emphasis",
  visitNode({ mdastNode, actions, lexicalParent }) {
    actions.addFormatting(IS_ITALIC);
    actions.visitChildren(mdastNode, lexicalParent);
  }
};
const MdStrongVisitor = {
  testNode: "strong",
  visitNode({ mdastNode, actions, lexicalParent }) {
    actions.addFormatting(IS_BOLD);
    actions.visitChildren(mdastNode, lexicalParent);
  }
};
const JsxUnderlineVisitor = {
  testNode: isJsxUnderlineNode,
  visitNode({ mdastNode, actions, lexicalParent }) {
    actions.addFormatting(IS_UNDERLINE);
    actions.visitChildren(mdastNode, lexicalParent);
  }
};
const OpeningUnderlineVisitor = {
  testNode: isOpeningUnderlineNode,
  visitNode({ actions, mdastParent }) {
    actions.addFormatting(IS_UNDERLINE, mdastParent);
  }
};
const ClosingUnderlineVisitor = {
  testNode: isClosingUnderlineNode,
  visitNode({ actions, mdastParent }) {
    actions.removeFormatting(IS_UNDERLINE, mdastParent);
  }
};
const formattingVisitors = [
  // emphasis
  MdEmphasisVisitor,
  // strong
  MdStrongVisitor,
  // underline
  JsxUnderlineVisitor,
  OpeningUnderlineVisitor,
  ClosingUnderlineVisitor,
  // code
  JsxCodeVisitor,
  OpeningCodeVisitor,
  ClosingCodeVisitor,
  MdCodeVisitor
];
export {
  formattingVisitors
};
